@@ -517,8 +517,8 @@ bool RegisterState::operator == ( const RegisterState & state ) const
 
 void RegisterState::print()
 {
-	cout << "   known="<<binary(known)<<endl;
-	cout << "   value="<<binary(value)<<endl;
+	cout << "   known=" << binary(known).local8Bit() << endl;
+	cout << "   value=" << binary(value).local8Bit() << endl;
 }
 //END class RegisterState
 
@@ -714,7 +714,7 @@ void ProcessorState::print()
 	RegisterMap::iterator end = m_registers.end();
 	for ( RegisterMap::iterator it = m_registers.begin(); it != end; ++it )
 	{
-		cout << " " << it.key().name() << ":\n";
+		cout << " " << it.key().name().local8Bit() << ":\n";
 		it.data().print();
 	}
 }
