@@ -27,7 +27,7 @@
 
 #include <assert.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <tqfile.h>
 #include <tqregexp.h>
 #include <tqstring.h>
