@@ -135,7 +135,7 @@ PIC14::Type PIC14::toType( const TQString & _text )
 	if ( text == "16F628" )
 		return P16F628;
 	
-	cerr << TQString("%1 is not a known PIC identifier\n").arg(_text);
+	cerr << TQString("%1 is not a known PIC identifier\n").arg(_text).local8Bit();
 	return unknown;
 }
 
