@@ -26,9 +26,9 @@
 
 #include <cmath>
 
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 
 #include <tqpainter.h>
 #include <tqtimer.h>
@@ -46,10 +46,10 @@ CMManager::CMManager( ItemDocument *itemDocument )
 	p_lastItemClicked = 0l;
 	m_drawAction = -1;
 	m_allowItemScrollTmr = new TQTimer(this);
-	connect( m_allowItemScrollTmr, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotAllowItemScroll()) );
+	connect( m_allowItemScrollTmr, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotAllowItemScroll()) );
 	
-	KGlobal::config()->setGroup("General");
-	slotSetManualRoute( KGlobal::config()->readBoolEntry( "ManualRouting", false ) );
+	TDEGlobal::config()->setGroup("General");
+	slotSetManualRoute( TDEGlobal::config()->readBoolEntry( "ManualRouting", false ) );
 }
 
 
@@ -336,8 +336,8 @@ void CMManager::setDrawAction( int drawAction )
 
 void CMManager::slotSetManualRoute( bool manualRoute )
 {
-	KGlobal::config()->setGroup("General");
-	KGlobal::config()->writeEntry( "ManualRouting", manualRoute );
+	TDEGlobal::config()->setGroup("General");
+	TDEGlobal::config()->writeEntry( "ManualRouting", manualRoute );
 	
 	setCMState( cms_manual_route, manualRoute );
 }
