@@ -61,7 +61,7 @@ information from those simulations back on the ICNDocument
 */
 class CircuitDocument : public ICNDocument
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		CircuitDocument( const TQString &caption, KTechlab *ktechlab, const char *name = 0L );
