@@ -20,7 +20,7 @@ class CircuitDocument;
 */
 class CircuitView : public ICNView
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	CircuitView( CircuitDocument *circuitDocument, ViewContainer *viewContainer, uint viewAreaId, const char *name = 0l );
