@@ -33,7 +33,7 @@ Document::Document( const TQString &caption, KTechlab *ktechlab, const char *nam
 	m_bDeleted(false)
 {
 	if (p_ktechlab)
-		connect( p_ktechlab, TQT_SIGNAL(configurationChanged()), this, TQT_SLOT(slotUpdateConfiguration()) );
+		connect( p_ktechlab, TQ_SIGNAL(configurationChanged()), this, TQ_SLOT(slotUpdateConfiguration()) );
 }
 
 
@@ -56,9 +56,9 @@ void Document::handleNewView( View *view )
 	m_viewList.append(view);
 	view->setDCOPID(m_nextViewID++);
 	view->setCaption(m_caption);
-	connect( view, TQT_SIGNAL(destroyed(TQObject* )), this, TQT_SLOT(slotViewDestroyed(TQObject* )) );
-	connect( view, TQT_SIGNAL(viewFocused(View* )), this, TQT_SLOT(slotViewFocused(View* )) );
-	connect( view, TQT_SIGNAL(viewUnfocused()), this, TQT_SIGNAL(viewUnfocused()) );
+	connect( view, TQ_SIGNAL(destroyed(TQObject* )), this, TQ_SLOT(slotViewDestroyed(TQObject* )) );
+	connect( view, TQ_SIGNAL(viewFocused(View* )), this, TQ_SLOT(slotViewFocused(View* )) );
+	connect( view, TQ_SIGNAL(viewUnfocused()), this, TQ_SIGNAL(viewUnfocused()) );
 	view->show();
 	view->setFocused();
 }
@@ -66,7 +66,7 @@ void Document::handleNewView( View *view )
 
 void Document::slotViewDestroyed( TQObject *obj )
 {
-	View *view = static_cast<View*>(TQT_TQWIDGET(obj));
+	View *view = static_cast<View*>(obj);
 	
 	m_viewList.remove(view);
 	
