@@ -75,7 +75,7 @@ typedef TQValueList<ElementMap> ElementMapList;
 */
 class Component : public CNItem
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		Component( ICNDocument *icnDocument, bool newItem, const TQString &id );
