@@ -48,7 +48,7 @@ ECPotentiometer::ECPotentiometer( ICNDocument *icnDocument, bool newItem, const
 	m_r1 = createResistance( createPin( -8, -24, 90, "n1" ), m_p1, 1. );
 	m_r2 = createResistance( createPin( -8, 24, 270, "n2" ), m_p1, 1. );
 	
-	Slider * s = addSlider( "slider", 0, 100, 5, 50, Qt::Vertical, TQRect( 0, -16, 16, 32 ) );
+	Slider * s = addSlider( "slider", 0, 100, 5, 50, TQt::Vertical, TQRect( 0, -16, 16, 32 ) );
 	m_pSlider = static_cast<TQSlider*>(s->widget());
 	
 	createProperty( "resistance", Variant::Type::Double );
