@@ -57,8 +57,8 @@ void initialize_ConsoleUI();
 extern void initialize_readline();
 extern void gui_main(void);
 extern void cli_main();
-KDE_EXPORT void gpsim_version() {};
-KDE_EXPORT void quit_gui() {};
+TDE_EXPORT void gpsim_version() {};
+TDE_EXPORT void quit_gui() {};
 
 
 //BEGIN class GpsimProcessor
