@@ -26,7 +26,7 @@
 Subcircuits::Subcircuits()
 	: TQObject()
 {
-	connect( ComponentSelector::self(), TQT_SIGNAL(itemRemoved(const TQString& )), this, TQT_SLOT(slotItemRemoved(const TQString& )) );
+	connect( ComponentSelector::self(), TQ_SIGNAL(itemRemoved(const TQString& )), this, TQ_SLOT(slotItemRemoved(const TQString& )) );
 }
 
 
