@@ -20,7 +20,7 @@ class FlowCodeDocument;
 */
 class FlowCodeView : public ICNView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		FlowCodeView( FlowCodeDocument *flowCodeDocument, ViewContainer *viewContainer, uint viewAreaId, const char *name = 0l );
