@@ -20,7 +20,7 @@ class RectangularOverlay;
 */
 class FlowContainer : public FlowPart
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	FlowContainer( ICNDocument *_icnView, bool newItem, const TQString &id );
