@@ -60,19 +60,19 @@ PinMapEditor::PinMapEditor( PinMapping * pinMapping, MicroInfo * picInfo, TQWidg
 	TQAccel * accel = new TQAccel( this );
 	accel->connectItem( accel->insertItem( Key_Delete ),
 						m_pPinMapDocument,
-						TQT_SLOT(deleteSelection()) );
+						TQ_SLOT(deleteSelection()) );
 	
 	accel->connectItem( accel->insertItem( TDEStdAccel::selectAll().keyCodeQt() ),
 						m_pPinMapDocument,
-						TQT_SLOT(selectAll()) );
+						TQ_SLOT(selectAll()) );
 	
 	accel->connectItem( accel->insertItem( TDEStdAccel::undo().keyCodeQt() ),
 						m_pPinMapDocument,
-						TQT_SLOT(undo()) );
+						TQ_SLOT(undo()) );
 	
 	accel->connectItem( accel->insertItem( TDEStdAccel::redo().keyCodeQt() ),
 						m_pPinMapDocument,
-						TQT_SLOT(redo()) );
+						TQ_SLOT(redo()) );
 	
 	
 	TQFrame * f = new TQFrame(this);
