@@ -22,7 +22,7 @@ spin box plus the SI magnitude symbol it is showing
 */
 class DoubleSpinBox : public TQSpinBox
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		DoubleSpinBox( double lower, double upper, double minAbs, double value, const TQString & unit, TQWidget * parent = 0 );
