@@ -35,7 +35,7 @@ namespace KateMDI { class ToolView; }
 */
 class ItemEditor : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		static ItemEditor * self( KateMDI::ToolView * parent = 0l );
