@@ -57,7 +57,7 @@ class ILVItem : public TQObject, public TDEListViewItem
 */
 class ItemSelector : public TDEListView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		ItemSelector( TQWidget *parent, const char *name );
@@ -121,7 +121,7 @@ class ItemSelector : public TDEListView
  */
 class ComponentSelector : public ItemSelector
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		static ComponentSelector * self( KateMDI::ToolView * parent = 0l );
@@ -139,7 +139,7 @@ class ComponentSelector : public ItemSelector
  */
 class FlowPartSelector : public ItemSelector
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		static FlowPartSelector * self( KateMDI::ToolView * parent = 0l );
@@ -156,7 +156,7 @@ class FlowPartSelector : public ItemSelector
  */
 class MechanicsSelector : public ItemSelector
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		static MechanicsSelector * self( KateMDI::ToolView * parent = 0l );
