@@ -24,7 +24,7 @@ class TQPushButton;
 */
 class OrientationWidget : public TQWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	OrientationWidget( TQWidget *parent = 0l, const char *name = 0l );
