@@ -26,7 +26,7 @@ Basic item, which holds the Variant data and Id for an item
 */
 class PLVItem : public TQObject, public TDEListViewItem
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		PLVItem( TDEListView *listview, const TQString &id, Variant * data );
