@@ -62,18 +62,18 @@ SettingsDlg::SettingsDlg( TQWidget *parent, const char *name, TDEConfigSkeleton
 	addPage( m_gpasmSettingsWidget, "Gpasm", "convert_to_hex", "gpasm" );
 	addPage( m_sdccOptionsWidget, "SDCC", "text-x-csrc", "SDCC" );
 	
-	connect( m_generalOptionsWidget->refreshRateSlider, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(slotUpdateRefreshRateLabel(int)) );
-	connect( m_picProgrammerConfigWidget->kcfg_PicProgrammerProgram, TQT_SIGNAL(activated(const TQString &)), this, TQT_SLOT(slotUpdatePicProgrammerDescription()) );
-	connect( m_picProgrammerConfigWidget->removeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotRemoveProgrammerConfig()) );
-	connect( m_picProgrammerConfigWidget->addButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotAddProgrammerConfig()) );
+	connect( m_generalOptionsWidget->refreshRateSlider, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(slotUpdateRefreshRateLabel(int)) );
+	connect( m_picProgrammerConfigWidget->kcfg_PicProgrammerProgram, TQ_SIGNAL(activated(const TQString &)), this, TQ_SLOT(slotUpdatePicProgrammerDescription()) );
+	connect( m_picProgrammerConfigWidget->removeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotRemoveProgrammerConfig()) );
+	connect( m_picProgrammerConfigWidget->addButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotAddProgrammerConfig()) );
 	
 	
-	connect( m_picProgrammerConfigWidget->initCommand, TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(slotSaveCurrentProgrammerConfig()) );
-	connect( m_picProgrammerConfigWidget->readCommand, TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(slotSaveCurrentProgrammerConfig()) );
-	connect( m_picProgrammerConfigWidget->writeCommand, TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(slotSaveCurrentProgrammerConfig()) );
-	connect( m_picProgrammerConfigWidget->verifyCommand, TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(slotSaveCurrentProgrammerConfig()) );
-	connect( m_picProgrammerConfigWidget->blankCheckCommand, TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(slotSaveCurrentProgrammerConfig()) );
-	connect( m_picProgrammerConfigWidget->eraseCommand, TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(slotSaveCurrentProgrammerConfig()) );
+	connect( m_picProgrammerConfigWidget->initCommand, TQ_SIGNAL(textChanged(const TQString &)), this, TQ_SLOT(slotSaveCurrentProgrammerConfig()) );
+	connect( m_picProgrammerConfigWidget->readCommand, TQ_SIGNAL(textChanged(const TQString &)), this, TQ_SLOT(slotSaveCurrentProgrammerConfig()) );
+	connect( m_picProgrammerConfigWidget->writeCommand, TQ_SIGNAL(textChanged(const TQString &)), this, TQ_SLOT(slotSaveCurrentProgrammerConfig()) );
+	connect( m_picProgrammerConfigWidget->verifyCommand, TQ_SIGNAL(textChanged(const TQString &)), this, TQ_SLOT(slotSaveCurrentProgrammerConfig()) );
+	connect( m_picProgrammerConfigWidget->blankCheckCommand, TQ_SIGNAL(textChanged(const TQString &)), this, TQ_SLOT(slotSaveCurrentProgrammerConfig()) );
+	connect( m_picProgrammerConfigWidget->eraseCommand, TQ_SIGNAL(textChanged(const TQString &)), this, TQ_SLOT(slotSaveCurrentProgrammerConfig()) );
 	
 	
 	m_generalOptionsWidget->kcfg_GridColor->setEnabled( KTLConfig::showGrid() );
@@ -300,7 +300,7 @@ void SettingsDlg::updateSettings()
 		emit settingsChanged();
 	}
 	
-	TQTimer::singleShot( 0, this, TQT_SLOT(slotUpdateSettings()) );
+	TQTimer::singleShot( 0, this, TQ_SLOT(slotUpdateSettings()) );
 }
 
 
@@ -346,7 +346,7 @@ void SettingsDlg::updateWidgets()
 	combo->insertStringList( programmerNames );
 	combo->setSizeLimit( programmerNames.size() );
 	
-	TQTimer::singleShot( 0, this, TQT_SLOT(slotUpdateWidgets()) );
+	TQTimer::singleShot( 0, this, TQ_SLOT(slotUpdateWidgets()) );
 }
 
 
