@@ -23,7 +23,7 @@
 #include "ktechlab.h"
 #include "nodegroup.h"
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
 #include <tqclipboard.h>
 #include <tqtimer.h>
@@ -963,7 +963,7 @@ bool ICNDocument::registerItem( TQCanvasItem *qcanvasItem )
 			{
 				Node *node = (Node*)qcanvasItem;
 				m_nodeList.append(node);
-				connect( node, TQT_SIGNAL(removed(Node*)), this, TQT_SLOT(requestRerouteInvalidatedConnectors()) );
+				connect( node, TQ_SIGNAL(removed(Node*)), this, TQ_SLOT(requestRerouteInvalidatedConnectors()) );
 				emit nodeAdded(node);
 				break;
 			}
@@ -971,7 +971,7 @@ bool ICNDocument::registerItem( TQCanvasItem *qcanvasItem )
 			{
 				Connector *connector = dynamic_cast<Connector*>(qcanvasItem);
 				m_connectorList.append(connector);
-				connect( connector, TQT_SIGNAL(removed(Connector*)), this, TQT_SLOT(requestRerouteInvalidatedConnectors()) );
+				connect( connector, TQ_SIGNAL(removed(Connector*)), this, TQ_SLOT(requestRerouteInvalidatedConnectors()) );
 				emit connectorAdded(connector);
 				break;
 			}
@@ -1030,7 +1030,7 @@ void ICNDocument::copy()
 	data.addNodes( nodeList );
 	data.addConnectors( connectorList );
 	
-	KApplication::clipboard()->setText( data.toXML(), TQClipboard::Clipboard );
+	TDEApplication::clipboard()->setText( data.toXML(), TQClipboard::Clipboard );
 }
 
 void ICNDocument::selectAll()
