@@ -8,6 +8,10 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "canvasmanipulator.h"
 #include "circuitdocument.h"
 #include "connector.h"
@@ -70,15 +74,15 @@ ItemDocument::ItemDocument( const TQString &caption, KTechlab *ktechlab, const c
 	m_canvas->setDoubleBuffering(true);
 	
 	m_pEventTimer = new TQTimer(this);
-	connect( m_pEventTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(processItemDocumentEvents()) );
+	connect( m_pEventTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(processItemDocumentEvents()) );
 	
-	connect( this, TQT_SIGNAL(itemSelected(Item*)), this, TQT_SLOT(slotInitItemActions(Item*)) );
-	connect( this, TQT_SIGNAL(itemUnselected(Item*)), this, TQT_SLOT(slotInitItemActions(Item*)) );
+	connect( this, TQ_SIGNAL(itemSelected(Item*)), this, TQ_SLOT(slotInitItemActions(Item*)) );
+	connect( this, TQ_SIGNAL(itemUnselected(Item*)), this, TQ_SLOT(slotInitItemActions(Item*)) );
 	
-	connect( ComponentSelector::self(),	TQT_SIGNAL(itemClicked(const TQString& )),		this, TQT_SLOT(slotUnsetRepeatedItemId()) );
-	connect( FlowPartSelector::self(),	TQT_SIGNAL(itemClicked(const TQString& )),		this, TQT_SLOT(slotUnsetRepeatedItemId()) );
+	connect( ComponentSelector::self(),	TQ_SIGNAL(itemClicked(const TQString& )),		this, TQ_SLOT(slotUnsetRepeatedItemId()) );
+	connect( FlowPartSelector::self(),	TQ_SIGNAL(itemClicked(const TQString& )),		this, TQ_SLOT(slotUnsetRepeatedItemId()) );
 #ifdef MECHANICS
-	connect( MechanicsSelector::self(),	TQT_SIGNAL(itemClicked(const TQString& )),		this, TQT_SLOT(slotUnsetRepeatedItemId()) );
+	connect( MechanicsSelector::self(),	TQ_SIGNAL(itemClicked(const TQString& )),		this, TQ_SLOT(slotUnsetRepeatedItemId()) );
 #endif
 
 	m_pAlignmentAction = new TDEActionMenu( i18n("Alignment"), "format-justify-right", this );
@@ -126,9 +130,9 @@ bool ItemDocument::registerItem( TQCanvasItem *qcanvasItem )
 		{
 			Item *item = dynamic_cast<Item*>(qcanvasItem);
 			m_itemList.append(item);
-			connect( item, TQT_SIGNAL(removed(Item*)), this, TQT_SLOT(requestRerouteInvalidatedConnectors()) );
-			connect( item, TQT_SIGNAL(selected(Item*,bool)), this, TQT_SIGNAL(itemSelected(Item*)) );
-			connect( item, TQT_SIGNAL(unselected(Item*,bool)), this, TQT_SIGNAL(itemUnselected(Item*)) );
+			connect( item, TQ_SIGNAL(removed(Item*)), this, TQ_SLOT(requestRerouteInvalidatedConnectors()) );
+			connect( item, TQ_SIGNAL(selected(Item*,bool)), this, TQ_SIGNAL(itemSelected(Item*)) );
+			connect( item, TQ_SIGNAL(unselected(Item*,bool)), this, TQ_SIGNAL(itemUnselected(Item*)) );
 			itemAdded(item);
 			return true;
 		}
@@ -807,7 +811,7 @@ void ItemDocument::exportToImage()
 	
 	// we need an object so we can retrieve which image type was selected by the user
 	// so setup the filedialog.
-	KFileDialog exportDialog(TQString(), "*.png|PNG Image\n*.bmp|BMP Image\n*.svg|SVG Image" , p_ktechlab, i18n("Export As Image"), true, cropCheck);
+	KFileDialog exportDialog(TQString(), "*.png|PNG Image\n*.bmp|BMP Image\n*.svg|SVG Image" , p_ktechlab, i18n("Export As Image").utf8(), true, cropCheck);
 	
 	exportDialog.setOperationMode( KFileDialog::Saving );
 	// now actually show it
@@ -877,12 +881,12 @@ void ItemDocument::exportToImage()
 	saveArea = m_canvas->rect();
 
 	if ( type == "PNG" || type == "BMP" )
-		outputImage = TQT_TQPAINTDEVICE(new TQPixmap( saveArea.size() ));
+		outputImage = new TQPixmap( saveArea.size() );
 	
 	else if ( type == "SVG" )
 	{
 		setSVGExport(true);
-		outputImage = TQT_TQPAINTDEVICE(new TQPicture());
+		outputImage = new TQPicture();
 		// svg can't be cropped using the qimage method.
 		saveArea = cropArea;
 	}
@@ -907,21 +911,25 @@ void ItemDocument::exportToImage()
 	if ( cropCheck->isChecked() )
 	{
 		if( type == "SVG" )
-			saveResult = dynamic_cast<TQPicture*>(outputImage)->save( url.path(), type);
+			saveResult = dynamic_cast<TQPicture*>(outputImage)->save(url.path(), type.utf8());
 		
 		else
 		{
 			TQImage img = dynamic_cast<TQPixmap*>(outputImage)->convertToImage();
 			img = img.copy(cropArea);
-			saveResult = img.save(url.path(),type);
+			saveResult = img.save(url.path(), type.utf8());
 		}
 	}
 	else
 	{
 		if ( type=="SVG" )
-			saveResult = dynamic_cast<TQPicture*>(outputImage)->save( url.path(), type );
+		{
+			saveResult = dynamic_cast<TQPicture*>(outputImage)->save(url.path(), type.utf8());
+		}
 		else
-			saveResult = dynamic_cast<TQPixmap*>(outputImage)->save( url.path(), type );
+		{
+			saveResult = dynamic_cast<TQPixmap*>(outputImage)->save(url.path(), type.utf8());
+		}
 	}
 	
 	//if(saveResult == true)	KMessageBox::information( this, i18n("Sucessfully exported to \"%1\"").arg( url.filename() ), i18n("Image Export") );
@@ -1211,7 +1219,7 @@ Canvas::Canvas( ItemDocument *itemDocument, const char * name )
 {
 	p_itemDocument = itemDocument;
 	m_pMessageTimeout = new TQTimer(this);
-	connect( m_pMessageTimeout, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotSetAllChanged()) );
+	connect( m_pMessageTimeout, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotSetAllChanged()) );
 }
 
 
