@@ -25,7 +25,7 @@ ItemGroup::ItemGroup( ItemDocument *view, const char *name )
 	p_view = view;
 	p_icnDocument = dynamic_cast<ICNDocument*>(p_view);
 	p_mechanicsDocument = dynamic_cast<MechanicsDocument*>(p_view);
-	TQTimer::singleShot( 0, this, TQT_SLOT(getViewPtrs()) );
+	TQTimer::singleShot( 0, this, TQ_SLOT(getViewPtrs()) );
 }
 
 
