@@ -37,7 +37,7 @@ void ExternalLanguage::deleteLanguageProcess()
 	
 	// I'm not too sure if this combination of killing the process is the best way....
 // 	m_languageProcess->tryTerminate();
-// 	TQTimer::singleShot( 5000, m_languageProcess, TQT_SLOT( kill() ) );
+// 	TQTimer::singleShot( 5000, m_languageProcess, TQ_SLOT( kill() ) );
 //  	delete m_languageProcess;
 	m_languageProcess->kill();
 	m_languageProcess->deleteLater();
@@ -126,14 +126,14 @@ void ExternalLanguage::resetLanguageProcess()
 	
 	m_languageProcess = new TDEProcess(this);
 	
-	connect( m_languageProcess, TQT_SIGNAL(receivedStdout( TDEProcess*, char*, int )),
-			 this, TQT_SLOT(receivedStdout( TDEProcess*, char*, int )) );
+	connect( m_languageProcess, TQ_SIGNAL(receivedStdout( TDEProcess*, char*, int )),
+			 this, TQ_SLOT(receivedStdout( TDEProcess*, char*, int )) );
 	
-	connect( m_languageProcess, TQT_SIGNAL(receivedStderr( TDEProcess*, char*, int )),
-			 this, TQT_SLOT(receivedStderr( TDEProcess*, char*, int )) );
+	connect( m_languageProcess, TQ_SIGNAL(receivedStderr( TDEProcess*, char*, int )),
+			 this, TQ_SLOT(receivedStderr( TDEProcess*, char*, int )) );
 	
-	connect( m_languageProcess, TQT_SIGNAL(processExited( TDEProcess* )),
-			 this, TQT_SLOT(processExited( TDEProcess* )) );
+	connect( m_languageProcess, TQ_SIGNAL(processExited( TDEProcess* )),
+			 this, TQ_SLOT(processExited( TDEProcess* )) );
 }
 
 
