@@ -44,8 +44,8 @@ void FlowCode::processInput( ProcessOptions options )
 		options.p_flowCodeDocument = new FlowCodeDocument( TQString(), 0l );
 		options.p_flowCodeDocument->openURL( options.inputFiles().first() );
 		
-		connect( this, TQT_SIGNAL(processSucceeded( Language *)), options.p_flowCodeDocument, TQT_SLOT(deleteLater()) );
-		connect( this, TQT_SIGNAL(processFailed( Language *)), options.p_flowCodeDocument, TQT_SLOT(deleteLater()) );
+		connect( this, TQ_SIGNAL(processSucceeded( Language *)), options.p_flowCodeDocument, TQ_SLOT(deleteLater()) );
+		connect( this, TQ_SIGNAL(processFailed( Language *)), options.p_flowCodeDocument, TQ_SLOT(deleteLater()) );
 	}
 
 	if ( !options.p_flowCodeDocument->microSettings() )
