@@ -20,7 +20,7 @@ class MechanicsDocument;
 */
 class MechanicsView : public ItemView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		MechanicsView( MechanicsDocument *mechanicsDocument, ViewContainer *viewContainer, uint viewAreaId, const char *name = 0l );
