@@ -208,7 +208,7 @@ class StoredData
  */
 class ProbeData : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
 	
 
 	public:
