@@ -19,7 +19,7 @@ Adapted to work around strange bug occuring.
 */
 class RecentFilesAction : public TDESelectAction
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		RecentFilesAction( const TQString & configGroupName, const TQString & text, const TQObject * receiver, const char* slot, TQObject* parent, const char * name );
