@@ -73,11 +73,11 @@ TextDocument::TextDocument( const TQString &caption, KTechlab *ktechlab, const c
 	
 	guessScheme();
 	
-	connect( m_doc, TQT_SIGNAL(undoChanged()),		this, TQT_SIGNAL(undoRedoStateChanged()) );
-	connect( m_doc, TQT_SIGNAL(undoChanged()),		this, TQT_SLOT(slotSyncModifiedStates()) );
-	connect( m_doc, TQT_SIGNAL(textChanged()),		this, TQT_SLOT(slotSyncModifiedStates()) );
-	connect( m_doc, TQT_SIGNAL(marksChanged()),		this, TQT_SLOT(slotUpdateMarksInfo()) );
-	connect( m_doc,	TQT_SIGNAL(selectionChanged()),	this, TQT_SLOT(slotSelectionmChanged()) );
+	connect( m_doc, TQ_SIGNAL(undoChanged()),		this, TQ_SIGNAL(undoRedoStateChanged()) );
+	connect( m_doc, TQ_SIGNAL(undoChanged()),		this, TQ_SLOT(slotSyncModifiedStates()) );
+	connect( m_doc, TQ_SIGNAL(textChanged()),		this, TQ_SLOT(slotSyncModifiedStates()) );
+	connect( m_doc, TQ_SIGNAL(marksChanged()),		this, TQ_SLOT(slotUpdateMarksInfo()) );
+	connect( m_doc,	TQ_SIGNAL(selectionChanged()),	this, TQ_SLOT(slotSelectionmChanged()) );
 	
 	m_doc->setDescription((KTextEditor::MarkInterface::MarkTypes)Breakpoint, i18n("Breakpoint"));
 	m_doc->setPixmap((KTextEditor::MarkInterface::MarkTypes)Breakpoint, *inactiveBreakpointPixmap());
@@ -170,9 +170,9 @@ void TextDocument::setText( const TQString & text, bool asInitial )
 {
 	if ( asInitial )
 	{
-		disconnect( m_doc, TQT_SIGNAL(undoChanged()), this, TQT_SIGNAL(undoRedoStateChanged()) );
-		disconnect( m_doc, TQT_SIGNAL(undoChanged()), this, TQT_SLOT(slotSyncModifiedStates()) );
-		disconnect( m_doc, TQT_SIGNAL(textChanged()), this, TQT_SLOT(slotSyncModifiedStates()) );
+		disconnect( m_doc, TQ_SIGNAL(undoChanged()), this, TQ_SIGNAL(undoRedoStateChanged()) );
+		disconnect( m_doc, TQ_SIGNAL(undoChanged()), this, TQ_SLOT(slotSyncModifiedStates()) );
+		disconnect( m_doc, TQ_SIGNAL(textChanged()), this, TQ_SLOT(slotSyncModifiedStates()) );
 	}
 
 	const ViewList::iterator end = m_viewList.end();
@@ -190,9 +190,9 @@ void TextDocument::setText( const TQString & text, bool asInitial )
 		m_doc->clearRedo();
 		setModified(false);
 	
-		connect( m_doc, TQT_SIGNAL(undoChanged()), this, TQT_SIGNAL(undoRedoStateChanged()) );
-		connect( m_doc, TQT_SIGNAL(undoChanged()), this, TQT_SLOT(slotSyncModifiedStates()) );
-		connect( m_doc, TQT_SIGNAL(textChanged()), this, TQT_SLOT(slotSyncModifiedStates()) );
+		connect( m_doc, TQ_SIGNAL(undoChanged()), this, TQ_SIGNAL(undoRedoStateChanged()) );
+		connect( m_doc, TQ_SIGNAL(undoChanged()), this, TQ_SLOT(slotSyncModifiedStates()) );
+		connect( m_doc, TQ_SIGNAL(textChanged()), this, TQ_SLOT(slotSyncModifiedStates()) );
 	}
 }
 
@@ -447,7 +447,7 @@ void TextDocument::convertToAssembly()
 		return;
 	
 	ProcessOptions o( dlg.info() );
-	o.setTextOutputTarget( m_pLastTextOutputTarget, this, TQT_SLOT(setLastTextOutputTarget( TextDocument* )) );
+	o.setTextOutputTarget( m_pLastTextOutputTarget, this, TQ_SLOT(setLastTextOutputTarget( TextDocument* )) );
 	o.setInputFiles(filePath);
 	o.setProcessPath( ProcessOptions::ProcessPath::path( ProcessOptions::guessMediaType(filePath), toType ) );
 	LanguageManager::self()->compile(o);
@@ -489,7 +489,7 @@ void TextDocument::convertToHex()
 		return;
 	
 	ProcessOptions o( dlg.info() );
-	o.setTextOutputTarget( m_pLastTextOutputTarget, this, TQT_SLOT(setLastTextOutputTarget( TextDocument* )) );
+	o.setTextOutputTarget( m_pLastTextOutputTarget, this, TQ_SLOT(setLastTextOutputTarget( TextDocument* )) );
 	o.setInputFiles(filePath);
 	o.setProcessPath( ProcessOptions::ProcessPath::path( ProcessOptions::guessMediaType(filePath), ProcessOptions::ProcessPath::Program ) );
 	LanguageManager::self()->compile(o);
@@ -604,7 +604,7 @@ void TextDocument::slotUpdateMarksInfo()
 		if ( mark->type & Bookmark )
 		{
 			TDEAction * a = new TDEAction( i18n("%1 - %2").arg( TQString::number( mark->line+1 ) ).arg( m_doc->textLine(mark->line) ),
-									   0, this, TQT_SLOT(slotBookmarkRequested()), this,
+									   0, this, TQ_SLOT(slotBookmarkRequested()), this,
 									   TQString("bookmark_%1").arg(TQString::number(mark->line)).latin1() );
 			m_bookmarkActions.append(a);
 		}
@@ -752,7 +752,7 @@ void TextDocument::debugRun()
 			break;
 	}
 	
-	m_symbolFile = GpsimProcessor::generateSymbolFile( m_debugFile, this, TQT_SLOT(slotCODCreationSucceeded()), TQT_SLOT(slotCODCreationFailed()) );
+	m_symbolFile = GpsimProcessor::generateSymbolFile( m_debugFile, this, TQ_SLOT(slotCODCreationSucceeded()), TQ_SLOT(slotCODCreationFailed()) );
 #endif // !NO_GPSIM
 }
 
@@ -973,9 +973,9 @@ void TextDocument::setDebugger( GpsimDebugger * debugger, bool ownDebugger )
 	if ( m_debugFile.isEmpty() )
 		m_debugFile = url().path();
 	
-	connect( m_pDebugger,			TQT_SIGNAL(destroyed()),						this, TQT_SLOT(slotDebuggerDestroyed()) );
-	connect( m_pDebugger->gpsim(),	TQT_SIGNAL(runningStatusChanged(bool )), 		this, TQT_SLOT(slotInitDebugActions()) );
-	connect( m_pDebugger,			TQT_SIGNAL(lineReached(const SourceLine &)),	this, TQT_SLOT(slotDebugSetCurrentLine(const SourceLine &)) );
+	connect( m_pDebugger,			TQ_SIGNAL(destroyed()),						this, TQ_SLOT(slotDebuggerDestroyed()) );
+	connect( m_pDebugger->gpsim(),	TQ_SIGNAL(runningStatusChanged(bool )), 		this, TQ_SLOT(slotInitDebugActions()) );
+	connect( m_pDebugger,			TQ_SIGNAL(lineReached(const SourceLine &)),	this, TQ_SLOT(slotDebugSetCurrentLine(const SourceLine &)) );
 	m_pDebugger->setBreakpoints( m_debugFile, breakpointList() );
 	
 	slotInitDebugActions();
